@@ -33,15 +33,16 @@ class FetchStep(ScaffoldStep):
     def run(self, context: ScaffoldContext, step: dict, runtime: ScaffoldRuntime):
         opts = render_options(step, context)
 
-        full_pkg_dir = context.resolve_package_path('.')
+        source = opts.get('source', '.')
+        full_pkg_dir = context.resolve_package_path(source)
         target = opts.get('target', '.')
         full_target = context.resolve_target_path(target)
-        source = opts.get('source', '**/*')
+        filter = opts.get('filter', '**/*')
 
         templates = opts.get('templates', [])
         exclude = opts.get('exclude', []) + ['.git', '.git/*']
 
-        paths = pathlib.Path(full_pkg_dir).rglob(source)
+        paths = pathlib.Path(full_pkg_dir).rglob(filter)
 
         for p_obj in paths:
             p = str(p_obj)
